<?php

namespace Provider1\Aboutus\Http\Controllers;
use Litepie\Aboutus\Http\Requests\AboutusRequest;
use Litepie\Aboutus\Models\Aboutus;

trait AboutusWorkflow {
	
    /**
     * Workflow controller function for aboutus.
     *
     * @param Model   $aboutus
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AboutusRequest $request, Aboutus $aboutus, $step)
    {

        try {

            $aboutus->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('aboutus::aboutus.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/aboutus/aboutus/' . $aboutus->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/aboutus/aboutus/' . $aboutus->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for aboutus.
     *
     * @param Model   $aboutus
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Aboutus $aboutus, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $aboutus->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('aboutus::aboutus.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.aboutus.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.aboutus.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.aboutus.message', $data)->render();

        }

    }
}