<?php

namespace Provider1\Aboutus\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Provider1\Aboutus\Http\Requests\AbtcategoryRequest;
use Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface;
use Provider1\Aboutus\Models\Abtcategory;

/**
 * Admin web controller class.
 */
class AbtcategoryAdminController extends BaseController
{
    // use AbtcategoryWorkflow;
    /**
     * Initialize abtcategory controller.
     *
     * @param type AbtcategoryRepositoryInterface $abtcategory
     *
     * @return type
     */
    public function __construct(AbtcategoryRepositoryInterface $abtcategory)
    {
        $this->repository = $abtcategory;
        parent::__construct();
    }

    /**
     * Display a list of abtcategory.
     *
     * @return Response
     */
    public function index(AbtcategoryRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('aboutus::abtcategory.names').' :: ');
        return $this->theme->of('aboutus::admin.abtcategory.index')->render();
    }

    /**
     * Display a list of abtcategory.
     *
     * @return Response
     */
    public function getJson(AbtcategoryRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $abtcategories  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\AbtcategoryListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $abtcategories['recordsTotal']    = $abtcategories['meta']['pagination']['total'];
        $abtcategories['recordsFiltered'] = $abtcategories['meta']['pagination']['total'];
        $abtcategories['request']         = $request->all();
        return response()->json($abtcategories, 200);

    }

    /**
     * Display abtcategory.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return Response
     */
    public function show(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        if (!$abtcategory->exists) {
            return response()->view('aboutus::admin.abtcategory.new', compact('abtcategory'));
        }

        Form::populate($abtcategory);
        return response()->view('aboutus::admin.abtcategory.show', compact('abtcategory'));
    }

    /**
     * Show the form for creating a new abtcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AbtcategoryRequest $request)
    {

        $abtcategory = $this->repository->newInstance([]);

        Form::populate($abtcategory);

        return response()->view('aboutus::admin.abtcategory.create', compact('abtcategory'));

    }

    /**
     * Create new abtcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AbtcategoryRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $abtcategory          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('aboutus::abtcategory.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/aboutus/abtcategory/'.$abtcategory->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show abtcategory for editing.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return Response
     */
    public function edit(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        Form::populate($abtcategory);
        return  response()->view('aboutus::admin.abtcategory.edit', compact('abtcategory'));
    }

    /**
     * Update the abtcategory.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return Response
     */
    public function update(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        try {

            $attributes = $request->all();

            $abtcategory->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('aboutus::abtcategory.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/aboutus/abtcategory/'.$abtcategory->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/aboutus/abtcategory/'.$abtcategory->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the abtcategory.
     *
     * @param Model   $abtcategory
     *
     * @return Response
     */
    public function destroy(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {

        try {

            $t = $abtcategory->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('aboutus::abtcategory.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/aboutus/abtcategory/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/aboutus/abtcategory/'.$abtcategory->getRouteKey()),
            ], 400);
        }
    }

}
