<?php

namespace Provider1\Aboutus\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Provider1\Aboutus\Http\Requests\AbtcategoryRequest;
use Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface;
use Provider1\Aboutus\Models\Abtcategory;

class AbtcategoryUserController extends BaseController
{
    /**
     * Initialize abtcategory controller.
     *
     * @param type AbtcategoryRepositoryInterface $abtcategory
     *
     * @return type
     */
    public function __construct(AbtcategoryRepositoryInterface $abtcategory)
    {
        $this->repository = $abtcategory;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Provider1\Aboutus\Repositories\Criteria\AbtcategoryUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AbtcategoryRequest $request)
    {
        $abtcategories = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('aboutus::abtcategory.names'));

        return $this->theme->of('aboutus::user.abtcategory.index', compact('abtcategories'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Abtcategory $abtcategory
     *
     * @return Response
     */
    public function show(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        Form::populate($abtcategory);

        return $this->theme->of('aboutus::user.abtcategory.show', compact('abtcategory'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AbtcategoryRequest $request)
    {

        $abtcategory = $this->repository->newInstance([]);
        Form::populate($abtcategory);

        $this->theme->prependTitle(trans('aboutus::abtcategory.names'));
        return $this->theme->of('aboutus::user.abtcategory.create', compact('abtcategory'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AbtcategoryRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $abtcategory = $this->repository->create($attributes);

            return redirect(trans_url('/user/aboutus/abtcategory'))
                -> with('message', trans('messages.success.created', ['Module' => trans('aboutus::abtcategory.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Abtcategory $abtcategory
     *
     * @return Response
     */
    public function edit(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {

        Form::populate($abtcategory);
        $this->theme->prependTitle(trans('aboutus::abtcategory.names'));

        return $this->theme->of('aboutus::user.abtcategory.edit', compact('abtcategory'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Abtcategory $abtcategory
     *
     * @return Response
     */
    public function update(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        try {
            $this->repository->update($request->all(), $abtcategory->getRouteKey());

            return redirect(trans_url('/user/aboutus/abtcategory'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('aboutus::abtcategory.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        try {
            $this->repository->delete($abtcategory->getRouteKey());
            return redirect(trans_url('/user/aboutus/abtcategory'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('aboutus::abtcategory.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
