<?php

namespace Provider1\Aboutus\Http\Controllers;
use Litepie\Aboutus\Http\Requests\AbtcategoryRequest;
use Litepie\Aboutus\Models\Abtcategory;

trait AbtcategoryWorkflow {
	
    /**
     * Workflow controller function for abtcategory.
     *
     * @param Model   $abtcategory
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AbtcategoryRequest $request, Abtcategory $abtcategory, $step)
    {

        try {

            $abtcategory->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('aboutus::abtcategory.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/abtcategory/abtcategory/' . $abtcategory->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/abtcategory/abtcategory/' . $abtcategory->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for abtcategory.
     *
     * @param Model   $abtcategory
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Abtcategory $abtcategory, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $abtcategory->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('aboutus::abtcategory.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.abtcategory.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.abtcategory.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('aboutus::admin.abtcategory.message', $data)->render();

        }

    }
}