<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Provider1\Aboutus\Interfaces\AboutusRepositoryInterface;
use Provider1\Aboutus\Repositories\Presenter\AboutusItemTransformer;

/**
 * Pubic API controller class.
 */
class AboutusPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Provider1\Aboutus\Interfaces\AboutusRepositoryInterface $aboutus
     *
     * @return type
     */
    public function __construct(AboutusRepositoryInterface $aboutus)
    {
        $this->repository = $aboutus;
        parent::__construct();
    }

    /**
     * Show aboutus's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $aboutuses = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\AboutusListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $aboutuses['code'] = 2000;
        return response()->json($aboutuses)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show aboutus.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $aboutus = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($aboutus)) {
            $aboutus         = $this->itemPresenter($module, new AboutusItemTransformer);
            $aboutus['code'] = 2001;
            return response()->json($aboutus)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
