<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Provider1\Aboutus\Http\Requests\AboutusRequest;
use Provider1\Aboutus\Interfaces\AboutusRepositoryInterface;
use Provider1\Aboutus\Models\Aboutus;

/**
 * User API controller class.
 */
class AboutusUserController extends BaseController
{
    /**
     * Initialize aboutus controller.
     *
     * @param type AboutusRepositoryInterface $aboutus
     *
     * @return type
     */
    public function __construct(AboutusRepositoryInterface $aboutus)
    {
        $this->repository = $aboutus;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Provider1\Aboutus\Repositories\Criteria\AboutusUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of aboutus.
     *
     * @return json
     */
    public function index(AboutusRequest $request)
    {
        $aboutuses  = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\AboutusListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $aboutuses['code'] = 2000;
        return response()->json($aboutuses) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display aboutus.
     *
     * @param Request $request
     * @param Model   Aboutus
     *
     * @return Json
     */
    public function show(AboutusRequest $request, Aboutus $aboutus)
    {

        if ($aboutus->exists) {
            $aboutus         = $aboutus->presenter();
            $aboutus['code'] = 2001;
            return response()->json($aboutus)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new aboutus.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AboutusRequest $request, Aboutus $aboutus)
    {
        $aboutus         = $aboutus->presenter();
        $aboutus['code'] = 2002;
        return response()->json($aboutus)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new aboutus.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AboutusRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $aboutus          = $this->repository->create($attributes);
            $aboutus          = $aboutus->presenter();
            $aboutus['code']  = 2004;

            return response()->json($aboutus)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show aboutus for editing.
     *
     * @param Request $request
     * @param Model   $aboutus
     *
     * @return json
     */
    public function edit(AboutusRequest $request, Aboutus $aboutus)
    {
        if ($aboutus->exists) {
            $aboutus         = $aboutus->presenter();
            $aboutus['code'] = 2003;
            return response()-> json($aboutus)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the aboutus.
     *
     * @param Request $request
     * @param Model   $aboutus
     *
     * @return json
     */
    public function update(AboutusRequest $request, Aboutus $aboutus)
    {
        try {

            $attributes = $request->all();

            $aboutus->update($attributes);
            $aboutus         = $aboutus->presenter();
            $aboutus['code'] = 2005;

            return response()->json($aboutus)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the aboutus.
     *
     * @param Request $request
     * @param Model   $aboutus
     *
     * @return json
     */
    public function destroy(AboutusRequest $request, Aboutus $aboutus)
    {

        try {

            $t = $aboutus->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('aboutus::aboutus.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
