<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Provider1\Aboutus\Http\Requests\AbtcategoryRequest;
use Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface;
use Provider1\Aboutus\Models\Abtcategory;

/**
 * Admin API controller class.
 */
class AbtcategoryAdminController extends BaseController
{
    /**
     * Initialize abtcategory controller.
     *
     * @param type AbtcategoryRepositoryInterface $abtcategory
     *
     * @return type
     */
    public function __construct(AbtcategoryRepositoryInterface $abtcategory)
    {
        $this->repository = $abtcategory;
        parent::__construct();
    }

    /**
     * Display a list of abtcategory.
     *
     * @return json
     */
    public function index(AbtcategoryRequest $request)
    {
        $abtcategories  = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\AbtcategoryListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $abtcategories['code'] = 2000;
        return response()->json($abtcategories) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display abtcategory.
     *
     * @param Request $request
     * @param Model   Abtcategory
     *
     * @return Json
     */
    public function show(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        $abtcategory         = $abtcategory->presenter();
        $abtcategory['code'] = 2001;
        return response()->json($abtcategory)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new abtcategory.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        $abtcategory         = $abtcategory->presenter();
        $abtcategory['code'] = 2002;
        return response()->json($abtcategory)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new abtcategory.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AbtcategoryRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $abtcategory          = $this->repository->create($attributes);
            $abtcategory          = $abtcategory->presenter();
            $abtcategory['code']  = 2004;

            return response()->json($abtcategory)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show abtcategory for editing.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return json
     */
    public function edit(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        $abtcategory         = $abtcategory->presenter();
        $abtcategory['code'] = 2003;
        return response()-> json($abtcategory)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the abtcategory.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return json
     */
    public function update(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        try {

            $attributes = $request->all();

            $abtcategory->update($attributes);
            $abtcategory         = $abtcategory->presenter();
            $abtcategory['code'] = 2005;

            return response()->json($abtcategory)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the abtcategory.
     *
     * @param Request $request
     * @param Model   $abtcategory
     *
     * @return json
     */
    public function destroy(AbtcategoryRequest $request, Abtcategory $abtcategory)
    {
        try {
            $t = $abtcategory->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('aboutus::abtcategory.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
