<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface;
use Provider1\Aboutus\Repositories\Presenter\AbtcategoryItemTransformer;

/**
 * Pubic API controller class.
 */
class AbtcategoryPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Provider1\Abtcategory\Interfaces\AbtcategoryRepositoryInterface $abtcategory
     *
     * @return type
     */
    public function __construct(AbtcategoryRepositoryInterface $abtcategory)
    {
        $this->repository = $abtcategory;
        parent::__construct();
    }

    /**
     * Show abtcategory's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $abtcategories = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\AbtcategoryListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $abtcategories['code'] = 2000;
        return response()->json($abtcategories)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show abtcategory.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $abtcategory = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($abtcategory)) {
            $abtcategory         = $this->itemPresenter($module, new AbtcategoryItemTransformer);
            $abtcategory['code'] = 2001;
            return response()->json($abtcategory)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
