<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Provider1\Aboutus\Http\Requests\QuoteRequest;
use Provider1\Aboutus\Interfaces\QuoteRepositoryInterface;
use Provider1\Aboutus\Models\Quote;

/**
 * Admin API controller class.
 */
class QuoteAdminController extends BaseController
{
    /**
     * Initialize quote controller.
     *
     * @param type QuoteRepositoryInterface $quote
     *
     * @return type
     */
    public function __construct(QuoteRepositoryInterface $quote)
    {
        $this->repository = $quote;
        parent::__construct();
    }

    /**
     * Display a list of quote.
     *
     * @return json
     */
    public function index(QuoteRequest $request)
    {
        $quotes  = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\QuoteListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $quotes['code'] = 2000;
        return response()->json($quotes) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display quote.
     *
     * @param Request $request
     * @param Model   Quote
     *
     * @return Json
     */
    public function show(QuoteRequest $request, Quote $quote)
    {
        $quote         = $quote->presenter();
        $quote['code'] = 2001;
        return response()->json($quote)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new quote.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(QuoteRequest $request, Quote $quote)
    {
        $quote         = $quote->presenter();
        $quote['code'] = 2002;
        return response()->json($quote)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new quote.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(QuoteRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $quote          = $this->repository->create($attributes);
            $quote          = $quote->presenter();
            $quote['code']  = 2004;

            return response()->json($quote)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show quote for editing.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return json
     */
    public function edit(QuoteRequest $request, Quote $quote)
    {
        $quote         = $quote->presenter();
        $quote['code'] = 2003;
        return response()-> json($quote)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the quote.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return json
     */
    public function update(QuoteRequest $request, Quote $quote)
    {
        try {

            $attributes = $request->all();

            $quote->update($attributes);
            $quote         = $quote->presenter();
            $quote['code'] = 2005;

            return response()->json($quote)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the quote.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return json
     */
    public function destroy(QuoteRequest $request, Quote $quote)
    {
        try {
            $t = $quote->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('aboutus::quote.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
