<?php

namespace Provider1\Aboutus\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Provider1\Aboutus\Interfaces\QuoteRepositoryInterface;
use Provider1\Aboutus\Repositories\Presenter\QuoteItemTransformer;

/**
 * Pubic API controller class.
 */
class QuotePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Provider1\Quote\Interfaces\QuoteRepositoryInterface $quote
     *
     * @return type
     */
    public function __construct(QuoteRepositoryInterface $quote)
    {
        $this->repository = $quote;
        parent::__construct();
    }

    /**
     * Show quote's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $quotes = $this->repository
            ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\QuoteListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $quotes['code'] = 2000;
        return response()->json($quotes)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show quote.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $quote = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($quote)) {
            $quote         = $this->itemPresenter($module, new QuoteItemTransformer);
            $quote['code'] = 2001;
            return response()->json($quote)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
