<?php

namespace Provider1\Aboutus\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Provider1\Aboutus\Http\Requests\QuoteRequest;
use Provider1\Aboutus\Interfaces\QuoteRepositoryInterface;
use Provider1\Aboutus\Models\Quote;

class QuoteUserController extends BaseController
{
    /**
     * Initialize quote controller.
     *
     * @param type QuoteRepositoryInterface $quote
     *
     * @return type
     */
    public function __construct(QuoteRepositoryInterface $quote)
    {
        $this->repository = $quote;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Provider1\Aboutus\Repositories\Criteria\QuoteUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(QuoteRequest $request)
    {
        $quotes = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('aboutus::quote.names'));

        return $this->theme->of('aboutus::user.quote.index', compact('quotes'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Quote $quote
     *
     * @return Response
     */
    public function show(QuoteRequest $request, Quote $quote)
    {
        Form::populate($quote);

        return $this->theme->of('aboutus::user.quote.show', compact('quote'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(QuoteRequest $request)
    {

        $quote = $this->repository->newInstance([]);
        Form::populate($quote);

        $this->theme->prependTitle(trans('aboutus::quote.names'));
        return $this->theme->of('aboutus::user.quote.create', compact('quote'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(QuoteRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $quote = $this->repository->create($attributes);

            return redirect(trans_url('/user/aboutus/quote'))
                -> with('message', trans('messages.success.created', ['Module' => trans('aboutus::quote.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Quote $quote
     *
     * @return Response
     */
    public function edit(QuoteRequest $request, Quote $quote)
    {

        Form::populate($quote);
        $this->theme->prependTitle(trans('aboutus::quote.names'));

        return $this->theme->of('aboutus::user.quote.edit', compact('quote'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Quote $quote
     *
     * @return Response
     */
    public function update(QuoteRequest $request, Quote $quote)
    {
        try {
            $this->repository->update($request->all(), $quote->getRouteKey());

            return redirect(trans_url('/user/aboutus/quote'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('aboutus::quote.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(QuoteRequest $request, Quote $quote)
    {
        try {
            $this->repository->delete($quote->getRouteKey());
            return redirect(trans_url('/user/aboutus/quote'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('aboutus::quote.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
