<?php

namespace Provider1\Aboutus\Policies;

use App\User;
use Provider1\Aboutus\Models\Aboutus;

class AboutusPolicy
{

    /**
     * Determine if the given user can view the aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function view(User $user, Aboutus $aboutus)
    {
        if ($user->canDo('aboutus.aboutus.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $aboutus->user_id;
    }

    /**
     * Determine if the given user can create a aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('aboutus.aboutus.create');
    }

    /**
     * Determine if the given user can update the given aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function update(User $user, Aboutus $aboutus)
    {
        if ($user->canDo('aboutus.aboutus.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $aboutus->user_id;
    }

    /**
     * Determine if the given user can delete the given aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function destroy(User $user, Aboutus $aboutus)
    {
        if ($user->canDo('aboutus.aboutus.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $aboutus->user_id;
    }

    /**
     * Determine if the given user can verify the given aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function verify(User $user, Aboutus $aboutus)
    {
        if ($user->canDo('aboutus.aboutus.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('aboutus.aboutus.verify') 
        && $user->is('manager')
        && $aboutus->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given aboutus.
     *
     * @param User $user
     * @param Aboutus $aboutus
     *
     * @return bool
     */
    public function approve(User $user, Aboutus $aboutus)
    {
        if ($user->canDo('aboutus.aboutus.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
