<?php

namespace Provider1\Aboutus\Policies;

use App\User;
use Provider1\Aboutus\Models\Abtcategory;

class AbtcategoryPolicy
{

    /**
     * Determine if the given user can view the abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function view(User $user, Abtcategory $abtcategory)
    {
        if ($user->canDo('aboutus.abtcategory.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $abtcategory->user_id;
    }

    /**
     * Determine if the given user can create a abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('aboutus.abtcategory.create');
    }

    /**
     * Determine if the given user can update the given abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function update(User $user, Abtcategory $abtcategory)
    {
        if ($user->canDo('aboutus.abtcategory.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $abtcategory->user_id;
    }

    /**
     * Determine if the given user can delete the given abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function destroy(User $user, Abtcategory $abtcategory)
    {
        if ($user->canDo('aboutus.abtcategory.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $abtcategory->user_id;
    }

    /**
     * Determine if the given user can verify the given abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function verify(User $user, Abtcategory $abtcategory)
    {
        if ($user->canDo('aboutus.abtcategory.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('aboutus.abtcategory.verify') 
        && $user->is('manager')
        && $abtcategory->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given abtcategory.
     *
     * @param User $user
     * @param Abtcategory $abtcategory
     *
     * @return bool
     */
    public function approve(User $user, Abtcategory $abtcategory)
    {
        if ($user->canDo('aboutus.abtcategory.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
