<?php

namespace Provider1\Aboutus\Policies;

use App\User;
use Provider1\Aboutus\Models\Quote;

class QuotePolicy
{

    /**
     * Determine if the given user can view the quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function view(User $user, Quote $quote)
    {
        if ($user->canDo('aboutus.quote.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $quote->user_id;
    }

    /**
     * Determine if the given user can create a quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('aboutus.quote.create');
    }

    /**
     * Determine if the given user can update the given quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function update(User $user, Quote $quote)
    {
        if ($user->canDo('aboutus.quote.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $quote->user_id;
    }

    /**
     * Determine if the given user can delete the given quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function destroy(User $user, Quote $quote)
    {
        if ($user->canDo('aboutus.quote.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $quote->user_id;
    }

    /**
     * Determine if the given user can verify the given quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function verify(User $user, Quote $quote)
    {
        if ($user->canDo('aboutus.quote.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('aboutus.quote.verify') 
        && $user->is('manager')
        && $quote->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given quote.
     *
     * @param User $user
     * @param Quote $quote
     *
     * @return bool
     */
    public function approve(User $user, Quote $quote)
    {
        if ($user->canDo('aboutus.quote.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
