<?php

namespace Provider1\Aboutus\Providers;

use Illuminate\Support\ServiceProvider;

class AboutusServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'aboutus');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'aboutus');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('aboutus', function ($app) {
            return $this->app->make('Provider1\Aboutus\Aboutus');
        });

// Bind Aboutus to repository
        $this->app->bind(
            \Provider1\Aboutus\Interfaces\AboutusRepositoryInterface::class,
            \Provider1\Aboutus\Repositories\Eloquent\AboutusRepository::class
        );
        // Bind Abtcategory to repository
        $this->app->bind(
            \Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface::class,
            \Provider1\Aboutus\Repositories\Eloquent\AbtcategoryRepository::class
        );
        // Bind Quote to repository
        $this->app->bind(
            \Provider1\Aboutus\Interfaces\QuoteRepositoryInterface::class,
            \Provider1\Aboutus\Repositories\Eloquent\QuoteRepository::class
        );

        $this->app->register(\Provider1\Aboutus\Providers\AuthServiceProvider::class);
        $this->app->register(\Provider1\Aboutus\Providers\EventServiceProvider::class);
        $this->app->register(\Provider1\Aboutus\Providers\RouteServiceProvider::class);
        // $this->app->register(\Provider1\Aboutus\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['aboutus'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('provider1/aboutus.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/aboutus')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/aboutus')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
