<?php

namespace Provider1\Aboutus\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Provider1\Aboutus\Models\Aboutus;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Provider1\Aboutus\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/aboutus/aboutus/*')) {
            Route::bind('aboutus', function ($aboutus) {
                $aboutusrepo = $this->app->make('\Provider1\Aboutus\Interfaces\AboutusRepositoryInterface');
                return $aboutusrepo->findorNew($aboutus);
            });
        }
if (Request::is('*/aboutus/abtcategory/*')) {
            Route::bind('abtcategory', function ($abtcategory) {
                $abtcategoryrepo = $this->app->make('\Provider1\Aboutus\Interfaces\AbtcategoryRepositoryInterface');
                return $abtcategoryrepo->findorNew($abtcategory);
            });
        }
if (Request::is('*/aboutus/quote/*')) {
            Route::bind('quote', function ($quote) {
                $quoterepo = $this->app->make('\Provider1\Aboutus\Interfaces\QuoteRepositoryInterface');
                return $quoterepo->findorNew($quote);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        // $this->mapApiRoutes();

        //
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        Route::group([
            'middleware' => 'web',
            'namespace' => $this->namespace,
            'prefix' => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace' => $this->namespace . '\Api',
            'prefix' => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/api.php');
        });
    }
}
