<?php

namespace Provider1\Aboutus\Workflow;

use Provider1\Aboutus\Models\Aboutus;
use Validator;

class AboutusValidator
{

    /**
     * Determine if the given aboutus is valid for complete status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function complete(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given aboutus is valid for verify status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function verify(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given aboutus is valid for approve status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function approve(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given aboutus is valid for publish status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function publish(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given aboutus is valid for archive status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function archive(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given aboutus is valid for unpublish status.
     *
     * @param Aboutus $aboutus
     *
     * @return bool / Validator
     */
    public function unpublish(Aboutus $aboutus)
    {
        return Validator::make($aboutus->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
