<?php

namespace Provider1\Aboutus\Workflow;

use Provider1\Aboutus\Models\Abtcategory;
use Validator;

class AbtcategoryValidator
{

    /**
     * Determine if the given abtcategory is valid for complete status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function complete(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given abtcategory is valid for verify status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function verify(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given abtcategory is valid for approve status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function approve(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given abtcategory is valid for publish status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function publish(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given abtcategory is valid for archive status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function archive(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given abtcategory is valid for unpublish status.
     *
     * @param Abtcategory $abtcategory
     *
     * @return bool / Validator
     */
    public function unpublish(Abtcategory $abtcategory)
    {
        return Validator::make($abtcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
