<?php

namespace Provider1\Aboutus\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Provider1\Aboutus\Models\Quote;

class QuoteAction
{
    /**
     * Perform the complete action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */
    public function complete(Quote $quote)
    {
        try {
            $quote->status = 'complete';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */public function verify(Quote $quote)
    {
        try {
            $quote->status = 'verify';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */public function approve(Quote $quote)
    {
        try {
            $quote->status = 'approve';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */public function publish(Quote $quote)
    {
        try {
            $quote->status = 'publish';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */
    public function archive(Quote $quote)
    {
        try {
            $quote->status = 'archive';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Quote $quote
     *
     * @return Quote
     */
    public function unpublish(Quote $quote)
    {
        try {
            $quote->status = 'unpublish';
            return $quote->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
